@@ -86,7 +86,7 @@ if (molData == null) molData =  new java.util.Hashtable ();
 var sb =  new JU.SB ();
 if (pc != null) {
 sb.appendI (nAtoms).appendC ('\n');
-for (var i = bsAtoms.nextSetBit (0), n = 0; i >= 0; i = bsAtoms.nextSetBit (i + 1)) sb.appendI (++n).append (" ").appendF (pc[i]).appendC ('\n');
+for (var i = bsAtoms.nextSetBit (0), n = 0; i >= 0; i = bsAtoms.nextSetBit (i + 1)) sb.appendI (++n).append (" ").appendD (pc[i]).appendC ('\n');
 
 molData.put ("jmol_partial_charges", sb.toString ());
 }sb.setLength (0);
@@ -133,7 +133,7 @@ mol.append ("{");
 if (a.getElementNumber () != 6) mol.append ("\"l\":\"").append (a.getElementSymbol ()).append ("\",");
 if (charge != 0) mol.append ("\"c\":").appendI (charge).append (",");
 if (isotope != 0) mol.append ("\"m\":").appendI (isotope).append (",");
-mol.append ("\"x\":").appendF (a.x).append (",\"y\":").appendF (a.y).append (",\"z\":").appendF (a.z).append ("}");
+mol.append ("\"x\":").appendD (a.x).append (",\"y\":").appendD (a.y).append (",\"z\":").appendD (a.z).append ("}");
 } else {
 mol.append (JU.PT.sprintf ("%10.4p%10.4p%10.4p", "p", o));
 mol.append (" ").append (sym);
@@ -204,11 +204,14 @@ if (is2d) {
 if (asJSON) {
 } else {
 switch (b.order) {
+case 1057:
+cfg = (asV3000 ? "  CFG=3" : "  4");
+break;
 case 1025:
 cfg = (asV3000 ? "  CFG=1" : "  1");
 break;
 case 1041:
-cfg = (asV3000 ? "  CFG=6" : "  3");
+cfg = (asV3000 ? "  CFG=2" : "  3");
 break;
 default:
 cfg = "  0";
@@ -239,7 +242,7 @@ mol.append ("{\"b\":").appendI (a1 - 1).append (",\"e\":").appendI (a2 - 1);
 if (order != 1) {
 mol.append (",\"o\":");
 if (order < 0) {
-mol.appendF (-order / 2);
+mol.appendD (-order / 2);
 } else {
 mol.appendI (order);
 }}mol.append ("}");
