@@ -267,7 +267,7 @@ if (i2 < i1) {
 var ii = i1;
 i1 = i2;
 i2 = ii;
-}var bondOrder = bond.getCovalentOrder ();
+}var bondOrder = (bond.isPartial () ? 0 : bond.getCovalentOrder ());
 switch (bondOrder) {
 case 0:
 continue;
