@@ -387,6 +387,8 @@ if (allowZipStream) return this.vwr.getJzt ().newZipInputStream (bis);
 o = this.vwr.getJzt ().getZipFileDirectory (bis, subFileList, 1, forceInputStream);
 } else if (JU.Rdr.isTar (bis)) {
 o = this.vwr.getJzt ().getZipFileDirectory (bis, subFileList, 1, forceInputStream);
+} else if (JU.Rdr.isBinary (bis, 16)) {
+return bis;
 }if (o != null) {
 if (!(Clazz.instanceOf (o, java.io.BufferedInputStream))) return (Clazz.instanceOf (o, String) ? JU.Rdr.getBR (o) : o);
 bis = JU.Rdr.getUnzippedInputStream (this.vwr.getJzt (), o);
@@ -432,29 +434,36 @@ out.write (bytes, 0, -1);
 return (bytes).length + " bytes";
 }, "~S,JU.OC");
 Clazz.defineMethod (c$, "getFileAsMap", 
-function (name, type) {
-var bdata =  new java.util.Hashtable ();
+function (name, type, asBytes) {
+var bdata = (asBytes ? null :  new java.util.Hashtable ());
 var t;
 if (name == null) {
 var errMsg =  new Array (1);
 var bytes = this.vwr.getImageAsBytes (type, -1, -1, -1, errMsg);
 if (errMsg[0] != null) {
+if (asBytes) return  Clazz.newByteArray (0, 0);
 bdata.put ("_ERROR_", errMsg[0]);
 return bdata;
-}t = JU.Rdr.getBIS (bytes);
+}if (bdata == null) return bytes;
+t = JU.Rdr.getBIS (bytes);
 } else {
 var data =  new Array (2);
 t = this.getFullPathNameOrError (name, true, data);
 if (Clazz.instanceOf (t, String)) {
+if (asBytes) return  Clazz.newByteArray (0, 0);
 bdata.put ("_ERROR_", t);
 return bdata;
 }if (!this.checkSecurity (data[0])) {
+if (asBytes) return  Clazz.newByteArray (0, 0);
 bdata.put ("_ERROR_", "java.io. Security exception: cannot read file " + data[0]);
 return bdata;
 }}try {
-this.vwr.getJzt ().readFileAsMap (t, bdata, name);
+if (asBytes) {
+return JU.Rdr.streamToBytes (t);
+}this.vwr.getJzt ().readFileAsMap (t, bdata, name);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
+if (asBytes) return  Clazz.newByteArray (0, 0);
 bdata.clear ();
 bdata.put ("_ERROR_", "" + e);
 } else {
@@ -462,7 +471,7 @@ throw e;
 }
 }
 return bdata;
-}, "~S,~S");
+}, "~S,~S,~B");
 Clazz.defineMethod (c$, "getFileDataAsString", 
 function (data, nBytesMax, doSpecialLoad, allowBinary, checkProtected) {
 data[1] = "";
