@@ -13,7 +13,7 @@
 // BH 6/1/2014 8:32:12 AM added Help button; better mouse/keypress handling
 // BH 1/5/2013 12:45:19 PM
 
-Jmol.Console = {
+;Jmol.Console = {
 	buttons:{},
 	buttonWidth:100,
 	click:function(id) {
@@ -355,3 +355,4 @@ Jmol.Console.Button.prototype.html = function() {
 	return s;
 }
 
+;
\ No newline at end of file
